/**
 * Copyright 2012-2013 Nikita Shmakov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.dreambrother.ljl;

/**
 * Central object in the 'Lightweight Java Logger' framework. Logging utils.
 * @author nik
 */
public interface Logger {
    
    /**
     * Log a debug message. Examples of usages: 
     * 
     * log.debug("Execute some code");
     * log.debug("Execute {} with {}", obj, args);
     * 
     * @param message log message
     * @param params params for the log message, optional
     */
    void debug(String message, Object... params);
    
    /**
     * Log a info message. Examples of usages:
     * 
     * log.info("Execute some code");
     * log.info("Execute {} with {}", obj, args);
     * 
     * @param message log message
     * @param params params for a log message, optional
     */
    void info(String message, Object... params);
    
    /**
     * Log a warn message. Examples of usages:
     * 
     * log.warn("Some problem was occured while executing some code");
     * log.warn("Some problem was occured while executing {} with {}", obj, args);
     * 
     * @param message log message
     * @param params params for a log message, optional
     */
    void warn(String message, Object... params);
    
    /**
     * Log an error message. Examples of usages:
     * 
     * log.error("Error was occured while executing some code");
     * log.error("Error was occured while executing {} with {}", obj, args);
     * 
     * @param message log message
     * @param params params for a log message, optional
     */
    void error(String message, Object... params);
}
