/**
 * Copyright 2012-2013 Nikita Shmakov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.dreambrother.ljl.impl;

import com.github.dreambrother.ljl.Logger;
import com.github.dreambrother.ljl.impl.appender.LogAppender;
import com.github.dreambrother.ljl.impl.configuration.LoggerConfigurationOperations;
import java.util.List;

/**
 * Default implementation of {@link Logger}.
 * @author nik
 */
public class LoggerImpl implements Logger {
    
    private final LoggerConfigurationOperations configurationOperations;
    
    private final Class<?> forClass;

    public LoggerImpl(Class<?> forClass, LoggerConfigurationOperations configurationOperations) {
        this.forClass = forClass;
        this.configurationOperations = configurationOperations;
    }

    @Override
    public void debug(String message, Object... params) {
        logMessage(LoggingLevel.DEBUG, message, params);
    }

    @Override
    public void info(String message, Object... params) {
        logMessage(LoggingLevel.INFO, message, params);
    }

    @Override
    public void warn(String message, Object... params) {
        logMessage(LoggingLevel.WARN, message, params);
    }

    @Override
    public void error(String message, Object... params) {
        logMessage(LoggingLevel.ERROR, message, params);
    }
    
    private void logMessage(LoggingLevel level, String message, Object... params) {
        List<LogAppender> appenders = configurationOperations.getAppenders(forClass, level);
        for (LogAppender appender : appenders) {
            appender.append(level, forClass, message, params);
        }
    }
}
