/**
 * Copyright 2012-2013 Nikita Shmakov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.dreambrother.ljl.impl.appender;

import com.github.dreambrother.ljl.impl.LoggingLevel;
import com.github.dreambrother.ljl.impl.formatter.LogFormatter;
import java.util.Date;
import java.util.concurrent.Executor;

/**
 *
 * @author nik
 */
public abstract class AbstractAppender implements LogAppender {

    private final LogFormatter formatter;
    private final Executor executor;

    public AbstractAppender(Executor executor, LogFormatter formatter) {
        this.executor = executor;
        this.formatter = formatter;
    }

    @Override
    public void append(final LoggingLevel level, final Class<?> clazz, 
            final String message, final Object... params) {
        
        executor.execute(new Runnable() {

            @Override
            public void run() {
                append(formatter.format(level, clazz, new Date(), message, params));
            }
        });
    }
    
    protected abstract void append(String message);

    public LogFormatter getFormatter() {
        return formatter;
    }

    public Executor getExecutor() {
        return executor;
    }
}
