/**
 * Copyright 2012-2013 Nikita Shmakov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.dreambrother.ljl.impl.configuration.reader;

import com.github.dreambrother.ljl.impl.LoggingLevel;
import org.codehaus.jackson.annotate.JsonProperty;

/**
 * @author nik
 */
public class LoggerConfigurationUnit {

    private final String packageName;
    private final String className;
    private final LoggingLevel level;
    private final String appender;
    private final String format;
    private final String maxFileSize;
    private final int maxFilesCount; 

    public LoggerConfigurationUnit(@JsonProperty("packageName") String packageName, 
            @JsonProperty("className") String className, 
            @JsonProperty("appender") String appender,
            @JsonProperty("level") LoggingLevel level,
            @JsonProperty("format") String format,
            @JsonProperty("maxFileSize") String maxFileSize,
            @JsonProperty("maxFilesCount") int maxFilesCount) {
        this.packageName = packageName;
        this.className = className;
        this.appender = appender;
        this.level = level;
        this.format = format;
        this.maxFileSize = maxFileSize;
        this.maxFilesCount = maxFilesCount;
    }

    public String getPackageName() {
        return packageName;
    }

    public String getClassName() {
        return className;
    }

    public String getAppender() {
        return appender;
    }

    public LoggingLevel getLevel() {
        return level;
    }

    public String getFormat() {
        return format;
    }

    public String getMaxFileSize() {
        return maxFileSize;
    }

    public int getMaxFilesCount() {
        return maxFilesCount;
    }

    @Override
    public String toString() {
        return "LoggerConfigurationUnit{" + "packageName=" + packageName + ", className=" + className 
                + ", level=" + level + ", appender=" + appender + ", format=" + format + ", maxFileSize=" 
                + maxFileSize + ", maxFilesCount=" + maxFilesCount + '}';
    }
}
