/**
 * Copyright 2012-2013 Nikita Shmakov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.dreambrother.ljl.impl.defaults;

import com.github.dreambrother.ljl.impl.LoggingLevel;
import com.github.dreambrother.ljl.impl.appender.ConsoleAppender;
import com.github.dreambrother.ljl.impl.appender.LogAppender;
import com.github.dreambrother.ljl.impl.configuration.LoggerConfigurationOperations;
import com.github.dreambrother.ljl.impl.configuration.reader.LoggerConfigurationState;
import com.github.dreambrother.ljl.impl.formatter.SimpleLogFormatter;
import java.util.Collections;
import java.util.List;
import java.util.concurrent.Executors;

/**
 * Default configuration.
 * Logs all messages, writer works in async mode with cached thread pool, 
 * log format: "[LEVEL] defaultDateToString threadName-className-message"
 * @author nik
 */
public class DefaultLoggerConfigurationOperations implements LoggerConfigurationOperations {
    
    private static final SimpleLogFormatter SIMPLE_LOG_FORMATTER = new SimpleLogFormatter();
    private static final LogAppender CONSOLE_APPENDER = new ConsoleAppender(
            Executors.newCachedThreadPool(), SIMPLE_LOG_FORMATTER);

    @Override
    public List<LogAppender> getAppenders(Class<?> clazz, LoggingLevel level) {
        return Collections.singletonList(CONSOLE_APPENDER);
    }

    @Override
    public void setState(LoggerConfigurationState state) {
    }
}
