/**
 * Copyright 2012-2013 Nikita Shmakov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.dreambrother.ljl.impl.formatter;

import com.github.dreambrother.ljl.impl.LoggingLevel;
import com.github.dreambrother.ljl.impl.utils.ArrayUtils;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
 *
 * @author nik
 */
public abstract class AbstractLogFormatter implements LogFormatter {

    @Override
    public String format(LoggingLevel level, Class<?> clazz, Date date, String message, Object... params) {
        validate(message, params);
        String result = message;
        for (Object object : params) {
            result = result.replaceFirst("\\{\\}", object.toString());
        }
        return performConcreteFormat(level, clazz, date, result);
    }

    protected abstract String performConcreteFormat(LoggingLevel level, Class<?> clazz, 
            Date date, String message);
    
    private void validate(String message, Object... params) {
        List<String> stringParams = new ArrayList<>(params.length);
        for (Object obj : params) {
            stringParams.add(obj.toString());
        }
        int nonEmptyParamsCount = ArrayUtils.getNonEmptyStringsCount(stringParams);
        int placeholdersCount = 0;
        for (int i = 0; i < message.length(); i++) {
            int index = message.indexOf("{}", i);
            if (index != -1) {
                placeholdersCount++;
                i = index;
            }
        }
        if (placeholdersCount != nonEmptyParamsCount) {
            throw new IllegalArgumentException("Invalid message format: " + message + ". Params: " 
                    + Arrays.toString(params));
        }
    }
}
