/**
 * Copyright 2012-2013 Nikita Shmakov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.dreambrother.ljl.impl.utils;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.net.URISyntaxException;
import java.net.URL;

/**
 *
 * @author nik
 */
public final class FileUtils {
    
    private static final String CLASSPATH_PREFIX = "classpath:";

    private FileUtils() { }

    public static File asFile(String filePath) {
        if (filePath.startsWith(CLASSPATH_PREFIX)) {
            try {
                URL resource = FileUtils.class.getResource(filePath.replace(CLASSPATH_PREFIX, ""));
                if (resource == null) {
                    throw new IllegalArgumentException("Invalid file path: " + filePath);
                }
                return new File(resource.toURI().getSchemeSpecificPart());
            } catch (URISyntaxException ex) {
                throw new IllegalArgumentException("Invalid file path: " + filePath, ex);
            }
        } else {
            return new File(filePath);
        }
    }
    
    public static InputStream asInputStream(String filePath) {
        if (filePath.startsWith(CLASSPATH_PREFIX)) {
            return FileUtils.class.getResourceAsStream(filePath.replace(CLASSPATH_PREFIX, ""));
        } else {
            try {
                return new FileInputStream(filePath);
            } catch (FileNotFoundException ex) {
                throw new IllegalArgumentException("File " + filePath + " was not found", ex);
            }
        }
    }
    
    public static void createParentDirectories(File file) {
        file.getAbsoluteFile().getParentFile().mkdirs();
    }
}
