/**
 * Copyright 2012-2013 Nikita Shmakov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.dreambrother.ljl;

import com.github.dreambrother.jload.annotations.LoadTest;
import com.github.dreambrother.ljl.impl.LoggerImpl;
import com.github.dreambrother.ljl.impl.LoggingLevel;
import com.github.dreambrother.ljl.impl.configuration.LoggerConfigurationOperationsImpl;
import com.github.dreambrother.ljl.impl.configuration.reader.LoggerConfigurationState;
import com.github.dreambrother.ljl.impl.configuration.reader.LoggerConfigurationUnit;
import java.util.Arrays;

/**
 *
 * @author nik
 */
public class LoggerLTCase {
    
    private String logFile1 = "target/tmp1.log";
    private String logFile2 = "target/tmp2.log";
    private LoggerConfigurationState syncConfiguration = new LoggerConfigurationState(false, 0, 
            Arrays.asList(new LoggerConfigurationUnit(null, LoggerLTCase.class.getName(), 
            "file:" + logFile1, LoggingLevel.DEBUG, 
            "[$level$] $thread$ $class$ $date:yyyy-MM-dd HH:mm:ss$ $msg$", null, 0)));
    private LoggerConfigurationState asyncConfiguration = new LoggerConfigurationState(true, 4, 
            Arrays.asList(new LoggerConfigurationUnit(null, LoggerLTCase.class.getName(), 
            "file:" + logFile2, LoggingLevel.DEBUG, 
            "[$level$] $thread$ $class$ $date:yyyy-MM-dd HH:mm:ss$ $msg$", null, 0)));
    
    private Logger syncLog = new LoggerImpl(LoggerLTCase.class, 
            new LoggerConfigurationOperationsImpl(syncConfiguration));
    private Logger asyncLog = new LoggerImpl(LoggerLTCase.class,
            new LoggerConfigurationOperationsImpl(asyncConfiguration));
    
    @LoadTest(iterationCount = 100000, threadCount = 4)
    public void testSyncConfigurationPerformance() {
        syncLog.info("Test message with params {} {}", "firstParam", "secondParam");
    }
    
    @LoadTest(iterationCount = 100000, threadCount = 4)
    public void testAsyncConfigurationPerformance() {
        asyncLog.info("Test message with params {} {}", "firstParam", "secondParam");
    }
}
