/**
 * Copyright 2012-2013 Nikita Shmakov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.dreambrother.ljl;

import com.github.dreambrother.ljl.impl.util.TestClass;
import java.io.File;
import java.io.FileWriter;
import java.lang.reflect.Field;
import org.junit.After;
import org.junit.Test;

/**
 * @author nik
 */
public class SystemTestCase {
    
    private final String config1 = "{\n" +
"        \"async\": \"false\",\n" +
"        \"loggers\": [{\n" +
"            \"packageName\": \"com.github\",\n" +
"            \"level\": \"DEBUG\",\n" +
"            \"appender\": \"console\",\n" +
"            \"format\": \"[$level$] $thread$ $class$ $date:yyyy-MM-dd HH:mm:ss$ $msg$\",\n" +
"            \"maxFileSize\": \"2 MB\",\n" +
"            \"maxFilesCount\": \"3\"" +
"        }]" +
"   }";
    
    private final String config2 = "{\n" +
"        \"poolSize\": \"4\",\n" +            
"        \"loggers\": [{\n" +
"            \"packageName\": \"com.github\",\n" +
"            \"level\": \"DEBUG\",\n" +
"            \"appender\": \"console\",\n" +
"            \"format\": \"$date:HH:mm:ss$ $class$ $msg$\"" +
"        }]" +
"   }";
    
    private final File tmpDir = new File("target/tmp");
    private final String customConfigPath = "target/tmp/ljl-properties.json";
    private final String classpathConfigName = "app-log-properties.json";
    private final String classpathConfigPath = "target/test-classes/" + classpathConfigName;

    @After
    public void clearConfiguration() throws Exception {
        final Field instanceField = LoggerFactory.class.getDeclaredField("INSTANCE");
        instanceField.setAccessible(true);
        final Field configurationField = LoggerFactory.class.getDeclaredField("loggerConfiguration");
        configurationField.setAccessible(true);
        configurationField.set(instanceField.get(null), null);
    }
    
    @Test
    public void testLoggerWithoutConfig() throws InterruptedException {
        final Logger log = LoggerFactory.getLogger(TestClass.class);
        logMessages(log, "Without config: ");
        
        Thread.sleep(100L); // wait for all async tasks
    }
    
    // TODO: test logger with default config
    
    @Test
    public void testLoggerWithCustomConfig() throws Exception {
        tmpDir.mkdir();
        try (FileWriter fw = new FileWriter(customConfigPath)) {
            fw.write(config1);
        }
        
        LoggerConfigurationPathHolder.getInstance().setConfigPath(customConfigPath);
        final Logger log = LoggerFactory.getLogger(TestClass.class);
        logMessages(log, "With default config: ");
    }
    
    @Test
    public void testLoggerWithClasspathConfig() throws Exception {
        try (FileWriter fw = new FileWriter(classpathConfigPath)) {
            fw.write(config2);
        }
        
        LoggerConfigurationPathHolder.getInstance().setConfigPath("classpath:/" + classpathConfigName);
        final Logger log = LoggerFactory.getLogger(TestClass.class);
        logMessages(log, "With custom config: ");
        
        Thread.sleep(100L);
    }
    
    private void logMessages(Logger log, String msgsPrefix) {
        log.debug(msgsPrefix + "DEBUG with params: {} {}", "test param 1", "test param 2");
        log.info(msgsPrefix + "INFO with param: {}", "sigle param");
        log.warn(msgsPrefix + "WARN without params");
        log.error(msgsPrefix + "ERROR without params");
    }
}
