/**
 * Copyright 2012-2013 Nikita Shmakov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.dreambrother.ljl.impl;

import com.github.dreambrother.ljl.Logger;
import com.github.dreambrother.ljl.impl.appender.LogAppender;
import com.github.dreambrother.ljl.impl.configuration.LoggerConfigurationOperations;
import com.github.dreambrother.ljl.impl.util.TestClass;
import java.util.Collections;
import org.easymock.EasyMock;
import org.junit.Before;
import org.junit.Test;

import static org.easymock.EasyMock.*;

/**
 * @author nik
 */
public class LoggerImplTest {
    
    private final LogAppender appenderMock = EasyMock.createMock(LogAppender.class);
    private final LoggerConfigurationOperations configurationOperationsMock = 
            EasyMock.createMock(LoggerConfigurationOperations.class);
    
    private final Object[] mocks = new Object[]{appenderMock, configurationOperationsMock};
    
    private final Class<?> testClass = TestClass.class;
    
    private final Logger log = new LoggerImpl(testClass, configurationOperationsMock);
    
    @Before
    public void tesetMocks() {
        reset(mocks);
    }
    
    @Test
    public void testInfo() {
        final String message = "Test";
        
        expect(configurationOperationsMock.getAppenders(testClass, LoggingLevel.INFO))
                .andReturn(Collections.singletonList(appenderMock));
        appenderMock.append(eq(LoggingLevel.INFO), eq(testClass), eq(message));
        
        // expect not allowed logging
        expect(configurationOperationsMock.getAppenders(testClass, LoggingLevel.DEBUG)).andReturn(Collections.EMPTY_LIST);
        replay(mocks);
        
        log.info(message);
        log.debug(message);
        
        verify(mocks);
    }
}
