/**
 * Copyright 2012-2013 Nikita Shmakov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.dreambrother.ljl.impl.configuration.reader;

import com.github.dreambrother.ljl.impl.LoggingLevel;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.List;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import static org.junit.Assert.*;

/**
 * @author nik
 */
public class ConfigurationReaderImplTest {
    
    private final String filePath = "tmp.json";
    private final String config = "{\n" +
"        \"loggers\": [{\n" +
"            \"packageName\": \"org.company.product\",\n" +
"            \"level\": \"WARN\",\n" +
"            \"appender\": \"console\"\n" +
"        }, {\n" +
"            \"packageName\": \"org.company.product.services\",\n" +
"            \"level\": \"INFO\",\n" +
"            \"appender\": \"console\"\n" +
"        }, {\n" +
"            \"className\": \"org.company.product.services.Service\",\n" +
"            \"level\": \"DEBUG\",\n" +
"            \"appender\": \"file:/path/to/file\"\n" +
"        }]\n" +
"    }";
    
    private final ConfigurationReader reader = new ConfigurationReaderImpl();
    
    @Before
    public void createConfig() throws IOException {
        try (FileWriter fw = new FileWriter(filePath)) {
            fw.write(config);
        }
    }
    
    @After
    public void deleteConfig() throws IOException {
        File file = new File(filePath);
        file.delete();
    }
    
    @Test
    public void testRead() {
        LoggerConfigurationState configState = reader.read(filePath);
        final List<LoggerConfigurationUnit> loggers = configState.getLoggers();
        assertEquals(3, loggers.size());
        assertNull(loggers.get(0).getClassName());
        assertEquals("org.company.product", loggers.get(0).getPackageName());
        assertEquals(LoggingLevel.WARN, loggers.get(0).getLevel());
        assertEquals("console", loggers.get(0).getAppender());
        assertNull(loggers.get(1).getClassName());
        assertEquals("org.company.product.services", loggers.get(1).getPackageName());
        assertEquals(LoggingLevel.INFO, loggers.get(1).getLevel());
        assertEquals("console", loggers.get(1).getAppender());
        assertNull(loggers.get(2).getPackageName());
        assertEquals("org.company.product.services.Service", loggers.get(2).getClassName());
        assertEquals(LoggingLevel.DEBUG, loggers.get(2).getLevel());
        assertEquals("file:/path/to/file", loggers.get(2).getAppender());
    }
}
