/**
 * Copyright 2012-2013 Nikita Shmakov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.dreambrother.ljl.impl.configuration.reader;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import static org.easymock.EasyMock.*;

/**
 *
 * @author nik
 */
public class FileListenerIntTest {

    private final File testFile = new File("1.test");
    private final Runnable callbackMock = createMock(Runnable.class);
    
    @Before
    public void prepare() {
        writeToFile(testFile, "init state");
    }
    
    @After
    public void clear() {
        if (testFile.exists()) {
            testFile.delete();
        }
    }
    
    @Test
    public void shouldInvokeCallbackWhenFileUpdates() throws InterruptedException {
        reset(callbackMock);
        callbackMock.run();
        expectLastCall().times(2);
        replay(callbackMock);
        
        FileListener sut = new FileListener(testFile, callbackMock);
        sut.startListening();
        Thread.sleep(100L);
        
        writeToFile(testFile, "test update 1");
        Thread.sleep(100L);
        writeToFile(testFile, "test update 2");
        Thread.sleep(100L);
        
        sut.stopListening();
        Thread.sleep(100L);
        
        verify(callbackMock);
    }
    
    @Test(expected = IllegalStateException.class)
    public void shouldThrowIllegalStateExceptionWhenInvokeStartListeningTwice() {
        FileListener sut = new FileListener(testFile, createNiceMock(Runnable.class));
        sut.startListening();
        sut.startListening();
    }
    
    @Test(expected = IllegalStateException.class)
    public void shouldThrowIllegalStateExceptionWhenInvokeStopListeningWithoutStartListening() {
        FileListener sut = new FileListener(testFile, callbackMock);
        sut.stopListening();
    }
    
    private void writeToFile(File file, String string) {
        try (FileWriter fw = new FileWriter(file, true)) {
            fw.write(string);
        } catch (IOException ex) {
            throw new AssertionError(ex.toString());
        }
    }
}
