/**
 * Copyright 2012-2013 Nikita Shmakov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.dreambrother.ljl.impl.formatter;

import com.github.dreambrother.ljl.impl.LoggingLevel;
import com.github.dreambrother.ljl.impl.util.TestClass;
import java.text.SimpleDateFormat;
import java.util.Date;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

/**
 * @author nik
 */
public class LogFormatterImplTest {

    @Test
    public void testLogFormatterWithoutDate() {
        final String pattern = "[$level$] $thread$ $class$ $msg$";
        final LogFormatter logFormatter = new LogFormatterImpl(pattern);
        final String msg = "Log message";
        
        assertEquals("[ERROR] " + Thread.currentThread().getName() + " " + TestClass.class.getName() + " " + msg, 
                logFormatter.format(LoggingLevel.ERROR, TestClass.class, new Date(), msg));
    }
    
    @Test
    public void testLogFormatterWithDate() {
        final String pattern = "[$level$] $thread$ $class$ $date$ $msg$";
        final LogFormatter logFormatter = new LogFormatterImpl(pattern);
        final String msg = "Log message";
        final Date date = new Date();
        
        assertEquals("[ERROR] " + Thread.currentThread().getName() + " " + TestClass.class.getName() + " " 
                + date + " " + msg, 
                logFormatter.format(LoggingLevel.ERROR, TestClass.class, date, msg));
    }
    
    @Test
    public void testLogFormatterWithDateFormat() {
        final String pattern = "[$level$] $thread$ $class$ $date:yyyy-MM-dd$ $msg$";
        final LogFormatter logFormatter = new LogFormatterImpl(pattern);
        final String msg = "Log message";
        final Date date = new Date();
        final SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd");
        
        assertEquals("[ERROR] " + Thread.currentThread().getName() + " " + TestClass.class.getName() + " " 
                + df.format(date) + " " + msg, 
                logFormatter.format(LoggingLevel.ERROR, TestClass.class, date, msg));
    }
    
    @Test
    public void testEmptyLogFormatter() {
        final LogFormatter logFormatter = new LogFormatterImpl("");
        assertEquals("", logFormatter.format(LoggingLevel.ERROR, TestClass.class, new Date(), "msg"));
    }
    
    @Test
    public void testLogWithParams() {
        final String pattern = "$msg$";
        final LogFormatter formatter = new LogFormatterImpl(pattern);
        final String logMessage = "message {}";
        
        assertEquals("message 1", formatter.format(null, null, null, logMessage, "1"));
    }
    
    @Test(expected = IllegalArgumentException.class)
    public void testInvalidLogMessage() {
        final String pattern = "$msg$";
        final LogFormatter formatter = new LogFormatterImpl(pattern);
        
        formatter.format(null, null, null, "msg {}{}", "only one param");
    }
}
